@@ -10,6 +10,23 @@ class TimestampedItem(models.Model):
         return self.title
 
 
+class SingleTimestampedItem(models.Model):
+    title = models.CharField('title', max_length=100)
+    modified = models.DateTimeField('modified', auto_now=True)
+
+    def __unicode__(self):
+        return self.title
+
+
+class DateStampedItem(models.Model):
+    title = models.CharField('title', max_length=100)
+    created = models.DateField('created', auto_now_add=True)
+    modified = models.DateTimeField('modified', auto_now=True)
+
+    def __unicode__(self):
+        return self.title
+
+
 class FakeTimestampedItem(models.Model):
     '''
     This model doesn't actually set it's timestamps, makes it easier
